Feedforward Closedloop Learning: Class Members

Feedforward Closedloop Learning

Here is a list of all documented class members with links to the class documentation for each member:

### - g -

- getAverageOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getBiasWeight() : feedforward_closedloop_learning.Neuron , Neuron
- getDecay() : feedforward_closedloop_learning.Neuron , Neuron
- getError() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- getEuclideanNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getFilterOutput() : feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank
- getInfinityNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getInput() : feedforward_closedloop_learning.Neuron , Neuron
- getLayer() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getLayers() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getManhattanNormOfWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getMask() : feedforward_closedloop_learning.Neuron , Neuron
- getMaxWeightValue() : feedforward_closedloop_learning.Neuron , Neuron
- getMinWeightValue() : feedforward_closedloop_learning.Neuron , Neuron
- getNeuron() : feedforward_closedloop_learning.Layer , Layer
- getNFiltersPerInput() : feedforward_closedloop_learning.FeedforwardClosedloopLearningWithFilterbank
- getNinputs() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron
- getNneurons() : feedforward_closedloop_learning.Layer , Layer
- getNumInputs() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getNumLayers() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getOutput() : Bandpass , feedforward_closedloop_learning.FeedforwardClosedloopLearning , feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , FeedforwardClosedloopLearning , Layer , Neuron
- getOutputLayer() : feedforward_closedloop_learning.FeedforwardClosedloopLearning , FeedforwardClosedloopLearning
- getSum() : feedforward_closedloop_learning.Neuron , Neuron
- getSumOfSquaredWeightVector() : feedforward_closedloop_learning.Neuron , Neuron
- getWeight() : feedforward_closedloop_learning.Neuron , Neuron
- getWeightDistanceFromInitialWeights() : feedforward_closedloop_learning.Layer , feedforward_closedloop_learning.Neuron , Layer , Neuron